pub struct ChainAuthenticator { /* private fields */ }Expand description
Authenticator that tries multiple authenticators in order.
The first authenticator to successfully authenticate the request wins. If all authenticators fail, the error from the last one is returned.
Implementations
Sourceimpl ChainAuthenticator
impl ChainAuthenticator
Sourcepub fn new(authenticators: Vec<Arc<dyn Authenticator>>) -> Self
pub fn new(authenticators: Vec<Arc<dyn Authenticator>>) -> Self
Creates a new chain authenticator with the given authenticators.
Sourcepub fn with(self, authenticator: Arc<dyn Authenticator>) -> Self
pub fn with(self, authenticator: Arc<dyn Authenticator>) -> Self
Adds an authenticator to the chain.